@@ -15,13 +15,13 @@
 #  limitations under the License.
 
 import re
-import types
 import copy
-from calculate.lib.cl_xml import xpath, xmlDoc
-from calculate.lib.cl_template import blocText
-from calculate.lib.format.samba import samba
+from ..cl_xml import xpath, xmlDoc, firstChild, insertBefore
+from copy import deepcopy
+from ..cl_template import blocText
+from .samba import samba
 
-class PlasmaArea(object):
+class PlasmaArea():
     def __init__(self):
         self.header = False
         self.start = False
@@ -86,26 +86,25 @@ class xmlDocPlasma(xmlDoc):
             fieldsRemove = xpath.Evaluate(
                 "descendant::field[child::action='drop']", xmlNewArea)
             for rmNode in fieldsRemove:
-                parentNode = rmNode.parentNode
-                parentNode.removeChild(rmNode)
+                parentNode = rmNode.getparent()
+                parentNode.remove(rmNode)
             captionAreasRemove = xpath.Evaluate(
                 "descendant::area/child::caption[child::action='drop']",
                 xmlNewArea)
             for rmNodeCapt in captionAreasRemove:
-                rmNode = rmNodeCapt.parentNode
-                parentNode = rmNode.parentNode
-                parentNode.removeChild(rmNode)
+                rmNode = rmNodeCapt.getparent()
+                parentNode = rmNode.getparent()
+                parentNode.remove(rmNode)
             self.setActionArea(xmlNewArea, "append")
             # Добавляем разделитель областей во вложенные области
             areaNodes = xpath.Evaluate('descendant::area', xmlNewArea)
             for areaNode in areaNodes:
                 self.setActionArea(areaNode, "append")
-                parentNode = areaNode.parentNode
-                parentNode.insertBefore(self.sepAreas.cloneNode(True),
-                                        areaNode)
-            baseNode.appendChild(xmlNewArea)
+                parentNode = areaNode.getparent()
+                insertBefore(parentNode, deepcopy(self.sepAreas), areaNode)
+            baseNode.append(xmlNewArea)
             # Добавляем разделитель областей
-            baseNode.insertBefore(self.sepAreas.cloneNode(True), xmlNewArea)
+            insertBefore(baseNode, deepcopy(self.sepAreas), xmlNewArea)
 
         nodesNames = xpath.Evaluate('child::area/caption/name', baseNode)
         nodesNewArea = xpath.Evaluate('child::caption/name', xmlNewArea)
@@ -119,55 +118,54 @@ class xmlDocPlasma(xmlDoc):
         if not nodesNames or not nodesNewArea:
             return False
         nameArea = ""
-        if nodesNewArea[0].firstChild:
-            nameArea = nodesNewArea[0].firstChild.nodeValue.strip()
+        if firstChild(nodesNewArea[0]) is not None:
+            nameArea = firstChild(nodesNewArea).text.strip()
         flagFindArea = False
         baseNodes = []
         newAreaAction = None
         for oName in nodesNames:
             newAreaAction = self.getActionArea(xmlNewArea)
-            oArea = oName.parentNode.parentNode
+            oArea = oName.getparent().getparent()
             oNameTxt = ""
-            if oName.firstChild:
-                oNameTxt = oName.firstChild.nodeValue
+            if firstChild(oName) is not None:
+                oNameTxt = firstChild(oName).text
             if nameArea == oNameTxt:
                 flagFindArea = True
                 # При использовании удаления
                 if newAreaAction == "drop":
-                    prevNode = oName.parentNode.parentNode.previousSibling
+                    prevNode = oName.getparent().getparent().getprevious()
                     removePrevNodes = []
                     while prevNode and self.getTypeField(prevNode) == "br":
                         removePrevNodes.append(prevNode)
-                        prevNode = prevNode.previousSibling
+                        prevNode = prevNode.getprevious()
                     for removeNode in removePrevNodes:
-                        baseNode.removeChild(removeNode)
-                    baseNode.removeChild(oName.parentNode.parentNode)
+                        baseNode.remove(removeNode)
+                    baseNode.remove(oName.getparent().getparent())
                     continue
                 elif newAreaAction == "replace":
-                    oldAreaNode = oName.parentNode.parentNode
+                    oldAreaNode = oName.getparent().getparent()
                     newAreaCaption = xpath.Evaluate('child::caption',
                                                     xmlNewArea)[0]
                     oldAreaCaption = xpath.Evaluate('child::caption',
                                                     oldAreaNode)[0]
                     if newAreaCaption and oldAreaCaption:
-                        xmlNewArea.replaceChild(oldAreaCaption, newAreaCaption)
+                        xmlNewArea.replace(newAreaCaption, oldAreaCaption)
                         self.setActionArea(xmlNewArea, "replace")
-                    baseNode.replaceChild(xmlNewArea,
-                                          oldAreaNode)
+                    baseNode.replace(oldAreaNode, xmlNewArea)
                     continue
-                baseNodes.append(oName.parentNode.parentNode)
+                baseNodes.append(oName.getparent().getparent())
 
                 # Заменяем QUOTE
-                oldAreaNode = oName.parentNode.parentNode
+                oldAreaNode = oName.getparent().getparent()
                 oldAreaQuote = xpath.Evaluate('child::caption/quote',
                                               oldAreaNode)[0]
-                if oldAreaQuote and not oldAreaQuote.firstChild:
+                if oldAreaQuote and firstChild(oldAreaQuote) is None:
                     newAreaQuote = xpath.Evaluate('child::caption/quote',
                                                   xmlNewArea)[0]
                     oldAreaCaption = xpath.Evaluate('child::caption',
                                                     oldAreaNode)[0]
-                    if newAreaQuote and oldAreaCaption:
-                        oldAreaCaption.replaceChild(newAreaQuote, oldAreaQuote)
+                    if newAreaQuote is not None and oldAreaCaption is not None:
+                        oldAreaCaption.replace(oldAreaQuote, newAreaQuote)
 
                 newFields = xpath.Evaluate('child::field', xmlNewArea)
 
@@ -228,7 +226,7 @@ class plasma(samba):
             if not listPath:
                 return ret
             flagList = False
-            if type(areaF) == list:
+            if isinstance(areaF, list):
                 fields = areaF
                 flagList = True
             else:
@@ -279,15 +277,14 @@ class plasma(samba):
             slpNamesBlock = reH.split(h)
             # Отступ слева для заголовка
             indentionLeft = slpNamesBlock[0]
-            namesBlock = filter(lambda x: x.strip(), slpNamesBlock)
+            namesBlock = [x for x in slpNamesBlock if x.strip()]
             # namesBlock = map(lambda x: self.removeSymbolTerm(x), namesBlock)
             findArea = findPathArea(copy.copy(namesBlock), areas)
             findAreaPrev = None
             namesBlockList.append(namesBlock)
             if findArea:
                 if len(namesBlock) > 1:
-                    namesBlockView = map(lambda x: self.removeSymbolTerm(x),
-                                         namesBlock)
+                    namesBlockView = (self.removeSymbolTerm(x) for x in namesBlock)
                 else:
                     namesBlockView = namesBlock
                 findArea.start = (indentionLeft + "[" +
@@ -305,9 +302,7 @@ class plasma(samba):
                         areaNew.header = nameB
                         if lenNamesBlock == i:
                             if len(namesBlock) > 1:
-                                namesBlockView = map(
-                                    lambda x: self.removeSymbolTerm(x),
-                                    namesBlock)
+                                namesBlockView = (self.removeSymbolTerm(x) for x in namesBlock)
                             else:
                                 namesBlockView = namesBlock
                             areaNew.start = (indentionLeft + "[" +
@@ -400,14 +395,14 @@ class plasma(samba):
 
                             self.createXML(f.fields, areaXMLChild, docObj)
 
-                            areaXML.appendChild(areaXMLChild)
+                            areaXML.append(areaXMLChild)
                         else:
                             self.createXML(f.fields, areaXML, docObj)
                         if "\n" in f.end:
                             fieldXMLBr = docObj.createField("br", [],
                                                             "", [],
                                                             False, False)
-                            areaXML.appendChild(fieldXMLBr)
+                            areaXML.append(fieldXMLBr)
                     else:
                         if not f:
                             continue
@@ -416,16 +411,16 @@ class plasma(samba):
                             if field.name is not False:
                                 fieldXML = self.createFieldTerm(
                                     field.name, field.value, field.br, docObj)
-                                areaXML.appendChild(fieldXML)
+                                areaXML.append(fieldXML)
                                 if field.br[-1] == "\n":
                                     fieldXMLBr = docObj.createField(
                                         "br", [], "", [], False, False)
-                                    areaXML.appendChild(fieldXMLBr)
+                                    areaXML.append(fieldXMLBr)
                             elif field.comment is not False:
                                 fieldXML = docObj.createField(
                                     "comment", [field.comment], "", [],
                                     False, False)
-                                areaXML.appendChild(fieldXML)
+                                areaXML.append(fieldXML)
                             elif field.br is not False:
                                 brText = field.br.replace("\n", "")
                                 if brText:
@@ -434,16 +429,16 @@ class plasma(samba):
                                 else:
                                     fieldXML = docObj.createField(
                                         'br', [], "", [], False, False)
-                                if areaXML and hasattr(areaXML, "appendChild"):
-                                    areaXML.appendChild(fieldXML)
+                                if areaXML is not None and hasattr(areaXML, "append"):
+                                    areaXML.append(fieldXML)
 
                 if i.header:
-                    rootNode.appendChild(areaXML)
+                    rootNode.append(areaXML)
                 if "\n" in i.end:
                     fieldXMLBr = docObj.createField("br", [],
                                                     "", [],
                                                     False, False)
-                    rootNode.appendChild(fieldXMLBr)
+                    rootNode.append(fieldXMLBr)
 
             else:
                 if not i:
@@ -454,15 +449,15 @@ class plasma(samba):
                         fieldXML = self.createFieldTerm(field.name,
                                                         field.value,
                                                         field.br, docObj)
-                        rootNode.appendChild(fieldXML)
+                        rootNode.append(fieldXML)
                         if field.br[-1] == "\n":
                             fieldXMLBr = docObj.createField("br", [], "", [],
                                                             False, False)
-                            rootNode.appendChild(fieldXMLBr)
+                            rootNode.append(fieldXMLBr)
                     elif field.comment is not False:
                         fieldXML = docObj.createField(
                             "comment", [field.comment], "", [], False, False)
-                        rootNode.appendChild(fieldXML)
+                        rootNode.append(fieldXML)
                     elif field.br is not False:
                         brText = field.br.replace("\n", "")
                         if brText:
@@ -471,8 +466,8 @@ class plasma(samba):
                         else:
                             fieldXML = docObj.createField(
                                 'br', [], "", [], False, False)
-                        rootNode.appendChild(fieldXML)
-                        # rootNode.appendChild(areaXML)
+                        rootNode.append(fieldXML)
+                        # rootNode.append(areaXML)
 
     def createTxtConfig(self, strHeader, dictVar):
         """Cоздает область с заголовком
@@ -483,7 +478,7 @@ class plasma(samba):
         if not strHeader:
             return ""
         if type(strHeader) in (tuple, list):
-            outTxt = "".join(map(lambda x: "[" + x + "]", strHeader))
+            outTxt = "".join(("[" + x + "]" for x in strHeader))
             if not outTxt:
                 return ""
             outTxt += "\n"
@@ -516,8 +511,8 @@ class plasma(samba):
             quotes = []
             xmlQuotes = xpath.Evaluate('child::caption/quote', xmlArea)
             for node in xmlQuotes:
-                if node.firstChild:
-                    quotes.append(node.firstChild.nodeValue)
+                if firstChild(node):
+                    quotes.append(firstChild(node).text)
             if len(quotes) == 0:
                 quotes.append("")
                 quotes.append("")
@@ -529,27 +524,27 @@ class plasma(samba):
         for xmlArea in xmlAreas:
             # Перед пустой областью и после нее удаляем переводы строк
             if getQuotesArea(xmlArea) == ["", ""]:
-                if (xmlArea.previousSibling and
+                if (xmlArea.getprevious() and
                             self.docObj.getTypeField(
-                                xmlArea.previousSibling) == "br"):
-                    parentNode = xmlArea.previousSibling.parentNode
-                    prev_prev_sbl = xmlArea.previousSibling.previousSibling
+                                xmlArea.getprevious()) == "br"):
+                    parentNode = xmlArea.getprevious().getparent()
+                    prev_prev_sbl = xmlArea.getprevious().getprevious()
                     if (prev_prev_sbl and
                                 self.docObj.getTypeField(
                                     prev_prev_sbl) == "br"):
-                        parentNode.removeChild(
-                            xmlArea.previousSibling.previousSibling)
-                    parentNode.removeChild(xmlArea.previousSibling)
-                if (xmlArea.nextSibling and
+                        parentNode.remove(
+                            xmlArea.getprevious().getprevious())
+                    parentNode.remove(xmlArea.getprevious())
+                if (xmlArea.getnext() and
                             self.docObj.getTypeField(
-                                xmlArea.nextSibling) == "br"):
-                    parentNode = xmlArea.nextSibling.parentNode
-                    next_next_sbl = xmlArea.nextSibling.nextSibling
+                                xmlArea.getnext()) == "br"):
+                    parentNode = xmlArea.getnext().getparent()
+                    next_next_sbl = xmlArea.getnext().getnext()
                     if (next_next_sbl and
                                 self.docObj.getTypeField(
                                     next_next_sbl) == "br"):
-                        parentNode.removeChild(xmlArea.nextSibling.nextSibling)
-                    parentNode.removeChild(xmlArea.nextSibling)
+                        parentNode.remove(xmlArea.getnext().getnext())
+                    parentNode.remove(xmlArea.getnext())
                 continue
 
             # Собираем поля в кучку
@@ -558,37 +553,37 @@ class plasma(samba):
                 childNodes = self.docObj.getFieldsArea(xmlArea)
                 firstChildArea = xmlChildAreas[0]
 
-                if (firstChildArea.previousSibling and
+                if (firstChildArea.getprevious() and
                             self.docObj.getTypeField(
-                                firstChildArea.previousSibling) == "br"):
+                                firstChildArea.getprevious()) == "br"):
                     prev_prev_sbl = (
-                        firstChildArea.previousSibling.previousSibling)
+                        firstChildArea.getprevious().getprevious())
                     if prev_prev_sbl:
                         if self.docObj.getTypeField(prev_prev_sbl) == "br":
-                            firstChildArea = firstChildArea.previousSibling
+                            firstChildArea = firstChildArea.getprevious()
                 flagFoundArea = False
                 it = 0
                 lenChild = len(childNodes)
                 for node in childNodes:
                     it += 1
-                    if node.tagName == "area":
+                    if node.tag == "area":
                         flagFoundArea = True
                         continue
-                    if flagFoundArea and node.tagName == "field":
+                    if flagFoundArea and node.tag == "field":
                         if self.docObj.getTypeField(node) == "var":
-                            xmlArea.insertBefore(node, firstChildArea)
+                            insertBefore(xmlArea, node, firstChildArea)
                             if it < lenChild:
                                 node_type = self.docObj.getTypeField(
                                     childNodes[it])
                                 if node_type == "br":
-                                    xmlArea.insertBefore(childNodes[it],
+                                    insertBefore(xmlArea, childNodes[it],
                                                          firstChildArea)
                     # Добавление перевода строк в если его нет между полями
                     if (self.docObj.getTypeField(node) == "var" and
-                            node.previousSibling and
+                            node.getprevious() and
                             not (self.docObj.getTypeField(
-                                node.previousSibling) in ("br", "comment"))):
-                        xmlArea.insertBefore(self.docObj.createField(
+                                node.getprevious()) in ("br", "comment"))):
+                        insertBefore(xmlArea, self.docObj.createField(
                             "br", [], "", [], False, False), node)
 
             # Добавляем BR если его нет первым полем
@@ -598,7 +593,7 @@ class plasma(samba):
                                  self.docObj.getTypeField(
                                      xmlFields[0]) == "comment")):
                 if xmlFields:
-                    xmlArea.insertBefore(self.docObj.createField("br",
+                    insertBefore(xmlArea, self.docObj.createField("br",
                                                                  [], "", [],
                                                                  False, False),
                                          xmlFields[0])
@@ -607,46 +602,46 @@ class plasma(samba):
                 for node in xmlFields:
                     # Добавление перевода строк в если его нет между полями
                     if (self.docObj.getTypeField(node) == "var" and
-                            node.previousSibling and
+                            node.getprevious() and
                             not (self.docObj.getTypeField(
-                                node.previousSibling) in ("br", "comment"))):
-                        xmlArea.insertBefore(self.docObj.createField("br",
+                                node.getprevious()) in ("br", "comment"))):
+                        insertBefore(xmlArea, self.docObj.createField("br",
                                                                      [], "", [],
                                                                      False,
                                                                      False),
                                              node)
             # Если последним полем BR, удаляем его
             if xmlFields and self.docObj.getTypeField(xmlFields[-1]) == "br":
-                if not xmlFields[-1].nextSibling:
-                    xmlArea.removeChild(xmlFields[-1])
+                if not xmlFields[-1].getnext():
+                    xmlArea.remove(xmlFields[-1])
 
             # Если предыдущим полем  не (BR или комментарий) - добавляем BR
-            if (xmlArea.previousSibling and
+            if (xmlArea.getprevious() and
                     not (self.docObj.getTypeField(
-                        xmlArea.previousSibling) == "br" or
+                        xmlArea.getprevious()) == "br" or
                                  self.docObj.getTypeField(
-                                     xmlArea.previousSibling) == "comment")):
-                parentNode = xmlArea.parentNode
-                parentNode.insertBefore(self.docObj.createField(
+                                     xmlArea.getprevious()) == "comment")):
+                parentNode = xmlArea.getparent()
+                insertBefore(parentNode, self.docObj.createField(
                     "br", [], "", [], False, False), xmlArea)
             # Если есть предыдущее поле, и поле предыдущеее предыдущему
             # не равно BR или комментарий то добавляем BR
-            if xmlArea.previousSibling:
-                prPrSibling = xmlArea.previousSibling.previousSibling
+            if xmlArea.getprevious():
+                prPrSibling = xmlArea.getprevious().getprevious()
                 if (prPrSibling and
                         not (self.docObj.getTypeField(
                             prPrSibling) == "br" or
                                      self.docObj.getTypeField(
                                          prPrSibling) == "comment")):
-                    parentNode = xmlArea.parentNode
-                    parentNode.insertBefore(self.docObj.createField(
+                    parentNode = xmlArea.getparent()
+                    insertBefore(parentNode, self.docObj.createField(
                         "br", [], "", [], False, False), xmlArea)
             # Если после есть BR а за ним ничего нет, удаляем BR
-            if (xmlArea.nextSibling and
-                        self.docObj.getTypeField(xmlArea.nextSibling) == "br"):
-                if not xmlArea.nextSibling.nextSibling:
-                    parentNode = xmlArea.nextSibling.parentNode
-                    parentNode.removeChild(xmlArea.nextSibling)
+            if (xmlArea.getnext() and
+                        self.docObj.getTypeField(xmlArea.getnext()) == "br"):
+                if not xmlArea.getnext().getnext():
+                    parentNode = xmlArea.getnext().getparent()
+                    parentNode.remove(xmlArea.getnext())
 
     def join(self, kdeObj):
         """Объединяем конфигурации"""
