@@ -446,7 +446,7 @@ class Fdisk(SizeableDisk, metaclass=ABCMeta):
                 self.fdisk.append("t\n%d\n%s\n" % (partnum, partid))
 
     def search_errors(self, errors):
-        return re.search(rb"Value out of range[.]|: unknown command",
+        return re.search(r"Value out of range[.]|: unknown command",
                          errors)
 
     def write(self):
