@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2008-2015 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2008-2016 Mir Calculate. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -18,23 +18,23 @@ import os
 import pwd
 import grp
 from os import environ, path
-from calculate.lib.datavars import Variable, VariableError, ReadonlyVariable
-from calculate.lib.utils.common import getPasswdUsers, isBootstrapDataOnly
-from calculate.lib.utils.files import listDirectory
+from ..datavars import Variable, VariableError, ReadonlyVariable
+from ..utils.common import getPasswdUsers, isBootstrapDataOnly
+from ..utils.files import listDirectory
 import sys
-from calculate.lib.cl_lang import setLocalTranslate
+from ..cl_lang import setLocalTranslate
 
 _ = lambda x: x
 setLocalTranslate('cl_lib3', sys.modules[__name__])
 
 try:
-    from calculate.lib.cl_ldap import ldapUser, ldap
+    from ..cl_ldap import ldapUser, ldap
 except ImportError:
     ldapUser = None
     ldap = None
 
 
-class LdapHelper(object):
+class LdapHelper():
     # data object from LDAP
     _ldapUserObject = False
     # user data from LDAP
@@ -67,11 +67,10 @@ class LdapHelper(object):
         user_obj = self.getLdapUserObject()
         if ldapUser and isinstance(user_obj, ldapUser):
             if user_obj.connectLdap():
-                return map(lambda x: x[0][1]['uid'][0],
-                           user_obj.ldapObj.ldapSearch(
+                return [ x[0][1]['uid'][0] for x in user_obj.ldapObj.ldapSearch(
                                user_obj.getUsersDN(),
                                ldap.SCOPE_ONELEVEL, '(objectClass=*)',
-                               ['uid']))
+                               ['uid'])]
         return []
 
 
@@ -125,7 +124,7 @@ class VariableUrGroup(ReadonlyVariable):
     def get(self):
         gid = self.Get('ur_gid')
         try:
-            return grp.getgrgid(gid).gr_name
+            return grp.getgrgid(str(gid)).gr_name
         except (KeyError, TypeError):
             return ""
 
